@@ -1,6 +1,5 @@
-"""Twisted runer: run and monitor processes
-
-Stability: semi-stable
+"""
+Twisted runer: run and monitor processes
 
 Maintainer: U{Andrew Bennetts<mailto:spiv@twistedmatrix.com>}
 
@@ -12,4 +11,5 @@ compatibility will be added.
 procmon:monitor and restart processes
 """
 
-__version__ = '0.1.0'
+from twisted.runner._version import version
+__version__ = version.short()
